class Site:
    """Collection of some useful sites for dorking"""
    # file sharing
    GOOGLEDRIVE = "drive.google.com"
    GOFILE = "gofile.io"
    ANONFILE = "anonfile.com"
    BAYFILES = "bayfiles.com"
    # pasting
    JUSTPASTE = "justpaste.it"
    FAMOUSPASTE = "famouspaste.com"
    PASTELINK = "pastelink.net"
    NULLBIN = "0bin.net"
    RENTRY = "rentry.co"
    PASTESITE = "pastesite.org"
    FREEPASTE = "freepaste.link"
    LEAKLINKS = "leaklinks.com"
    JUSTPASTE = "justpaste.it"
    PASTEBIN = "pastebin.com"
    # lists
    LIST_FILESHARING = [GOOGLEDRIVE, GOFILE, ANONFILE, BAYFILES]
    LIST_PASTING = [JUSTPASTE, FAMOUSPASTE, PASTELINK, NULLBIN, RENTRY, PASTESITE, FREEPASTE, LEAKLINKS, JUSTPASTE, PASTEBIN]